==> scathach-api-1.4.1.tar.gz: scathach-api-1.4.1/README.md <==
# scathach-api
A Python module, complete rewrite and overhaul of the original Fate/Lewd Order API.

# Install
```
pip install scathach-api
```

### Endpoints
NOTE: You must call them as functions  

| Function | Description |
| -------- | ----------- |
| `ahegao` | Gets a nsfwURL of a ahegao face |
| `jav` | Gets a nsfwURL of a jav image |
| `gif` | Gets a nsfwURL of a gif |
| `twitter` | Gets a nsfwURL of a twitter |
| `fgo` | Gets a nsfwURL of a Fate/Grand Order image/gif |
| `furry` | Gets a nsfwURL of a furry image/gif |
| `armpits`  | Get a nsfwURL of a armpits image/gif |
| `ass` | Get a nsfwURL of a ass image/gif |
| `bikini` | Get a nsfwURL of a bikini image/gif |
| `blowjob` | Get a nsfwURL of a blowjob image/gif |
| `blush` | Get a nsfwURL of a blush image/gif |
| `clothed_sex` | Get a nsfwURL of a clothed_sex image/gif |
| `cowgirl_position` | Get a nsfwURL of a cowgirl_position image/gif |
| `cum` | Get a nsfwURL of a cum |
| `dark_skin` | Get a nsfwURL of a dark_skin image |
| `doggystyle` | Get a nsfwURL of a doggystyle image/gif |
| `double_penetration` | Get a nsfwURL of a double_penetration |
| `foot_licking` | Get a nsfwURL of a foot_licking image/gif |
| `footjob` | Get a nsfwURL of a footjob image/gif |
| `furry` | Get a nsfwURL of a furry image/gif |
| `futanari` | Get a nsfwURL of a futanari image/gif |
| `gangbang` | Get a nsfwURL of a gangbang image/gif |
| `housewife` | Get a nsfwURL of a housewife |
| `impregnation` | Get a nsfwURL of a impregnation image |
| `large_breasts` | Get a nsfwURL of a large_breasts image/gif |
| `masturbation` | Get a nsfwURL of a masturbation |
| `milf` | Get a nsfwURL of a milf image/gif |
| `netorare` | Get a nsfwURL of a netorare image/gif |
| `pantyhose` | Get a nsfwURL of a pantyhose image/gif |
| `pervert` | Get a nsfwURL of a pervert |
| `pout` | Get a nsfwURL of a pout image |
| `pregnant` | Get a nsfwURL of a pregnant image/gif |
| `pubic_hair` | Get a nsfwURL of a pubic_hair |
| `pussy_juice` | Get a nsfwURL of a pussy_juice image/gif |
| `rape` | Get a nsfwURL of a rape image/gif |
| `school_uniform` | Get a nsfwURL of a school_uniform image/gif |
| `smell` | Get a nsfwURL of a smell image/gif |
| `sweat` | Get a nsfwURL of a sweat image/gif |
| `thick` | Get a nsfwURL of a thick |
| `twintails` | Get a nsfwURL of a twintails image |
| `ugly_man` | Get a nsfwURL of a ugly_man image/gif |
| `uncensored` | Get a nsfwURL of a uncensored |
| `yaoi` | Get a nsfwURL of a yaoi image/gif |
| `yuri` | Get a nsfwURL of a yuri |  

# Usage example
```py
import scathach
print(scathach.fgo())

>>> 'https://us.rule34.xxx/images/3825/9711466f0b8fb65112b53349ef48c613.png'
```

==> scathach-api-1.4.2.tar.gz: scathach-api-1.4.2/README.md <==
# scathach-api
An advanced NSFW wrapper, complete rewrite and overhaul of the original Fate/Lewd Order API.

# Install
```
pip install scathach-api
```

### Endpoints
NOTE: You must call them as functions  

| Function | Description |
| -------- | ----------- |
| `ahegao` | Gets a nsfwURL of a ahegao face |
| `jav` | Gets a nsfwURL of a jav image |
| `gif` | Gets a nsfwURL of a gif |
| `twitter` | Gets a nsfwURL of a twitter |
| `fgo` | Gets a nsfwURL of a Fate/Grand Order image/gif |
| `furry` | Gets a nsfwURL of a furry image/gif |
| `armpits`  | Get a nsfwURL of a armpits image/gif |
| `ass` | Get a nsfwURL of a ass image/gif |
| `bikini` | Get a nsfwURL of a bikini image/gif |
| `blowjob` | Get a nsfwURL of a blowjob image/gif |
| `blush` | Get a nsfwURL of a blush image/gif |
| `clothed_sex` | Get a nsfwURL of a clothed_sex image/gif |
| `cowgirl_position` | Get a nsfwURL of a cowgirl_position image/gif |
| `cum` | Get a nsfwURL of a cum |
| `dark_skin` | Get a nsfwURL of a dark_skin image |
| `doggystyle` | Get a nsfwURL of a doggystyle image/gif |
| `double_penetration` | Get a nsfwURL of a double_penetration |
| `foot_licking` | Get a nsfwURL of a foot_licking image/gif |
| `footjob` | Get a nsfwURL of a footjob image/gif |
| `furry` | Get a nsfwURL of a furry image/gif |
| `futanari` | Get a nsfwURL of a futanari image/gif |
| `gangbang` | Get a nsfwURL of a gangbang image/gif |
| `housewife` | Get a nsfwURL of a housewife |
| `impregnation` | Get a nsfwURL of a impregnation image |
| `large_breasts` | Get a nsfwURL of a large_breasts image/gif |
| `masturbation` | Get a nsfwURL of a masturbation |
| `milf` | Get a nsfwURL of a milf image/gif |
| `netorare` | Get a nsfwURL of a netorare image/gif |
| `pantyhose` | Get a nsfwURL of a pantyhose image/gif |
| `pervert` | Get a nsfwURL of a pervert |
| `pout` | Get a nsfwURL of a pout image |
| `pregnant` | Get a nsfwURL of a pregnant image/gif |
| `pubic_hair` | Get a nsfwURL of a pubic_hair |
| `pussy_juice` | Get a nsfwURL of a pussy_juice image/gif |
| `rape` | Get a nsfwURL of a rape image/gif |
| `school_uniform` | Get a nsfwURL of a school_uniform image/gif |
| `smell` | Get a nsfwURL of a smell image/gif |
| `sweat` | Get a nsfwURL of a sweat image/gif |
| `thick` | Get a nsfwURL of a thick |
| `twintails` | Get a nsfwURL of a twintails image |
| `ugly_man` | Get a nsfwURL of a ugly_man image/gif |
| `uncensored` | Get a nsfwURL of a uncensored |
| `yaoi` | Get a nsfwURL of a yaoi image/gif |
| `yuri` | Get a nsfwURL of a yuri |  

# Usage example
```py
import scathach
print(scathach.fgo())

>>> 'https://us.rule34.xxx/images/3825/9711466f0b8fb65112b53349ef48c613.png'
```
